# spyder-remote-server

[![GitHub](https://img.shields.io/github/license/Semi-ATE/spyder-remote?color=black)](https://github.com/Semi-ATE/spyder-remote/blob/master/LICENSE.txt) 
[![Conda](https://img.shields.io/conda/pn/conda-forge/starz?color=black)](https://www.lifewire.com/what-is-noarch-package-2193808)
[![Supported Python versions](https://img.shields.io/badge/python-%3E%3D3.7-black)](https://www.python.org/downloads/)

[![CI](https://github.com/Semi-ATE/spyder-remote/workflows/CI/badge.svg)](https://github.com/Semi-ATE/spyder-remote/actions?query=workflow%3ACI)
[![CD](https://github.com/Semi-ATE/spyder-remote/workflows/CD/badge.svg)](https://github.com/Semi-ATE/spyder-remote/actions?query=workflow%3ACD)

[![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/Semi-ATE/spyder-remote?color=blue&label=GitHub&sort=semver)](https://github.com/Semi-ATE/spyder-remote/releases)
[![Server on PyPI](https://img.shields.io/pypi/v/spyder-remote-server?color=blue&label=PyPI)](https://pypi.org/project/spyder-remote-server/)
[![Server on Conda](https://img.shields.io/conda/vn/conda-forge/spyder-remote-server?color=blue&label=conda-forge)](https://anaconda.org/conda-forge/spyder-remote-server)
[![server feedstock](https://img.shields.io/github/issues-pr/conda-forge/spyder-remote-server-feedstock?label=feedstock)](https://github.com/conda-forge/spyder-remote-server-feedstock)
[![PyPI - Server Downloads](https://img.shields.io/pypi/dm/spyder-remote-server?color=g&label=PyPi)](https://pypi.org/project/spyder-remote-server/)
[![conda - Server Downloads](https://img.shields.io/conda/dn/conda-forge/spyder-remote-server?color=g&label=conda-forge)](https://anaconda.org/conda-forge/spyder-remote-server)

Spyder remote server to connect to Spyder kernels via zeroconf.
